"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var core_1 = require('@angular/core');
/**
 * This class represents the navigation bar component.
 */
var FeatureFlagComponent = (function () {
    /**
    * Class constructor
    */
    function FeatureFlagComponent(featureFlags, differs) {
        this.differs = differs;
        // if this attribute is true, shows the feature
        this.condition = false;
        this.differ = differs.find({}).create(null);
        this.features = featureFlags;
    }
    /**
    * When the class init
    */
    FeatureFlagComponent.prototype.ngOnInit = function () {
        // do all the conditions calculations
        this.calculateConditions();
        this.differ.diff({
            language: this.language,
            country: this.country,
            userRole: this.userRole
        });
    };
    FeatureFlagComponent.prototype.ngDoCheck = function () {
        var changes = this.differ.diff({
            language: this.language,
            country: this.country,
            userRole: this.userRole
        });
        if (changes) {
            this.calculateConditions();
        }
    };
    /*
    * Check all the conditions
    */
    FeatureFlagComponent.prototype.calculateConditions = function () {
        var featureConditions = this.features[this.feature];
        try {
            // check if there is configuration for a given feature
            if (typeof featureConditions == "undefined") {
                throw "no_configuration(" + this.feature + ")";
            }
            // final resul (true or false) for all the calculations
            var finalResult = true;
            // the possible properties to evaluate for  feature flag conditions
            // TODO1: remove items that are not present in configuration file for a given item
            var properties = ["country", "language", "userRole"];
            // current values of the component, parameters of the feature flag
            var componentValues = {
                country: (typeof this.country != "undefined" ? this.country : null),
                language: (typeof this.language != "undefined" ? this.language : null),
                userRole: (typeof this.userRole != "undefined" ? this.userRole : null)
            };
            // evaluate all the properties for this feature
            for (var itemProperty in properties) {
                // value for each proerty and it's id
                var propertyId = properties[itemProperty];
                var itemValue = featureConditions[propertyId];
                var componentValue = componentValues[propertyId];
                // assume that the property condition is valid
                var propertyCondition = true;
                // consider array or single value
                if (typeof itemValue === "undefined") {
                }
                else if (typeof itemValue === "string") {
                    // it's a simple string (normalized to lowercase)
                    propertyCondition = itemValue.toLowerCase() == componentValue.toLowerCase();
                }
                else {
                    // it's an array, first normalize values to lowercase
                    var lowerCaseItemValue = itemValue.map(function (value) {
                        return value.toUpperCase();
                    });
                    // check  this condition is true
                    propertyCondition = lowerCaseItemValue.indexOf(componentValue.toLowerCase()) > -1;
                }
                // stop when the first condition is not true
                if (!propertyCondition) {
                    finalResult = false;
                    break;
                }
            }
            // assign the final condition value to update the tempalte
            this.condition = finalResult;
        }
        catch (err) {
            console.error("[feature_flags] [Error] : " + err);
        }
    };
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], FeatureFlagComponent.prototype, "feature", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], FeatureFlagComponent.prototype, "country", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], FeatureFlagComponent.prototype, "language", void 0);
    __decorate([
        core_1.Input(), 
        __metadata('design:type', String)
    ], FeatureFlagComponent.prototype, "userRole", void 0);
    FeatureFlagComponent = __decorate([
        core_1.Component({
            selector: 'feature-flag',
            template: '<ng-content *ngIf="condition"></ng-content>'
        }),
        __param(0, core_1.Inject('featureFlags')), 
        __metadata('design:paramtypes', [Object, core_1.KeyValueDiffers])
    ], FeatureFlagComponent);
    return FeatureFlagComponent;
}());
exports.FeatureFlagComponent = FeatureFlagComponent;
//# sourceMappingURL=feature-flag.component.js.map